@@ -1,7 +1,7 @@
 /*
  * libopenraw - cameraids.h
  *
- * Copyright (C) 2012-2022 Hubert Figuière
+ * Copyright (C) 2012-2023 Hubert Figuière
  *
  * This library is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -219,6 +219,7 @@ enum _OR_TYPEID_VENDOR_CANON {
     OR_TYPEID_CANON_250D = 94,
     OR_TYPEID_CANON_REBEL_SL3 = OR_TYPEID_CANON_250D,
     OR_TYPEID_CANON_KISS_X10 = OR_TYPEID_CANON_250D,
+    OR_TYPEID_CANON_200D_MKII = OR_TYPEID_CANON_250D,
     OR_TYPEID_CANON_G7XMKIII = 95,
     OR_TYPEID_CANON_G5XMKII = 96,
     OR_TYPEID_CANON_EOS_M6MKII = 97,
@@ -243,6 +244,11 @@ enum _OR_TYPEID_VENDOR_CANON {
     OR_TYPEID_CANON_EOS_M50MKII = 114,
     OR_TYPEID_CANON_KISS_M2 = OR_TYPEID_CANON_EOS_M50MKII,
     OR_TYPEID_CANON_EOS_R3 = 115,
+    OR_TYPEID_CANON_EOS_R7 = 116,
+    OR_TYPEID_CANON_EOS_R10 = 117,
+    OR_TYPEID_CANON_EOS_R6MKII = 118,
+    OR_TYPEID_CANON_EOS_R8 = 119,
+    OR_TYPEID_CANON_EOS_R50 = 120,
     _OR_TYPEID_CANON_LAST
 };
 
@@ -333,6 +339,11 @@ enum _OR_TYPEID_VENDOR_NIKON {
     OR_TYPEID_NIKON_Z7_2,
     OR_TYPEID_NIKON_ZFC,
     OR_TYPEID_NIKON_Z9,
+    OR_TYPEID_NIKON_D1H,
+    OR_TYPEID_NIKON_D7500,
+    OR_TYPEID_NIKON_D850,
+    OR_TYPEID_NIKON_COOLPIX_P7800,
+    OR_TYPEID_NIKON_Z30,
     _OR_TYPEID_NIKON_LAST
 };
 
@@ -388,6 +399,10 @@ enum _OR_TYPEID_VENDOR_LEICA {
     OR_TYPEID_LEICA_SL2S = 36,
     OR_TYPEID_LEICA_Q2_MONOCHROM = 37,
     OR_TYPEID_LEICA_M11 = 38,
+    /* Panasonic RAW */
+    OR_TYPEID_LEICA_DIGILUX3 = 39,
+    /* RWL */
+    OR_TYPEID_LEICA_DLUX_6 = 40,
     _OR_TYPEID_LEICA_LAST
 };
 
@@ -449,6 +464,7 @@ enum _OR_TYPEID_VENDOR_PENTAX {
     OR_TYPEID_PENTAX_K110D_PEF,
     OR_TYPEID_PENTAX_K3_MKIII_PEF = 54,
     OR_TYPEID_PENTAX_K3_MKIII_DNG,
+    OR_TYPEID_PENTAX_K2000_PEF = 56,
     _OR_TYPEID_PENTAX_LAST
 };
 
@@ -457,6 +473,7 @@ enum _OR_TYPEID_VENDOR_EPSON {
     OR_TYPEID_EPSON_UNKNOWN = 0,
     OR_TYPEID_EPSON_RD1 = 1,
     OR_TYPEID_EPSON_RD1S = 2,
+    OR_TYPEID_EPSON_RD1X = 3,
     _OR_TYPEID_EPSON_LAST
 };
 
@@ -531,6 +548,16 @@ enum _OR_TYPEID_VENDOR_OLYMPUS {
     OR_TYPEID_OLYMPUS_EM10IV = 51,
     OR_TYPEID_OLYMPUS_EM10IIIS = 52,
     OR_TYPEID_OLYMPUS_OM1 = 53,
+    OR_TYPEID_OLYMPUS_E30 = 54,
+    OR_TYPEID_OLYMPUS_EP5 = 55,
+    OR_TYPEID_OLYMPUS_E420 = 56,
+    OR_TYPEID_OLYMPUS_E450 = 57,
+    OR_TYPEID_OLYMPUS_E520 = 58,
+    OR_TYPEID_OLYMPUS_E600 = 59,
+    OR_TYPEID_OLYMPUS_C5060WZ = 60,
+    OR_TYPEID_OLYMPUS_SP570UZ = 61,
+    OR_TYPEID_OLYMPUS_EP7 = 62,
+    OR_TYPEID_OLYMPUS_OM5 = 63,
 
     _OR_TYPEID_OLYMPUS_LAST
 };
@@ -656,6 +683,9 @@ enum _OR_TYPEID_VENDOR_SONY {
     OR_TYPEID_SONY_ILCE7RM3A = 87,
     OR_TYPEID_SONY_ILCE7RM4A = 88,
     OR_TYPEID_SONY_HX95 = 89,
+    OR_TYPEID_SONY_ILCE7RM5 = 90,
+    OR_TYPEID_SONY_ZVE1 = 91,
+    OR_TYPEID_SONY_ILME_FX30 = 92,
     _OR_TYPEID_SONY_LAST
 };
 
@@ -691,6 +721,7 @@ enum _OR_TYPEID_VENDOR_PANASONIC {
     OR_TYPEID_PANASONIC_GF6 = 27,
     OR_TYPEID_PANASONIC_GX7 = 28,
     OR_TYPEID_PANASONIC_GM1 = 29,
+    OR_TYPEID_PANASONIC_GM1S = OR_TYPEID_PANASONIC_GM1,
     OR_TYPEID_PANASONIC_GH4 = 30,
     OR_TYPEID_PANASONIC_LX100 = 31,
     OR_TYPEID_PANASONIC_GM5 = 32,
@@ -704,6 +735,7 @@ enum _OR_TYPEID_VENDOR_PANASONIC {
     OR_TYPEID_PANASONIC_ZS100 = 37,
     OR_TYPEID_PANASONIC_TX1 = OR_TYPEID_PANASONIC_ZS100,
     OR_TYPEID_PANASONIC_TZ100 = OR_TYPEID_PANASONIC_ZS100,
+    OR_TYPEID_PANASONIC_TZ101 = OR_TYPEID_PANASONIC_ZS100,
     OR_TYPEID_PANASONIC_TZ110 = OR_TYPEID_PANASONIC_ZS100,
     OR_TYPEID_PANASONIC_GX80 = 38,
     OR_TYPEID_PANASONIC_GX85 = OR_TYPEID_PANASONIC_GX80,
@@ -715,10 +747,12 @@ enum _OR_TYPEID_VENDOR_PANASONIC {
     OR_TYPEID_PANASONIC_TZ70 = 43,
     OR_TYPEID_PANASONIC_ZS60 = 44,
     OR_TYPEID_PANASONIC_TZ80 = OR_TYPEID_PANASONIC_ZS60,
+    OR_TYPEID_PANASONIC_TZ81 = OR_TYPEID_PANASONIC_ZS60,
 
     OR_TYPEID_PANASONIC_GF7 = 46,
     OR_TYPEID_PANASONIC_CM1 = 47,
     OR_TYPEID_PANASONIC_GX9 = 48,
+    OR_TYPEID_PANASONIC_GX7MK3 = OR_TYPEID_PANASONIC_GX9,
     OR_TYPEID_PANASONIC_GX800 = 49,
 
     OR_TYPEID_PANASONIC_G9 = 52,
@@ -727,6 +761,7 @@ enum _OR_TYPEID_VENDOR_PANASONIC {
     OR_TYPEID_PANASONIC_LX1 = 55,
     OR_TYPEID_PANASONIC_FZ150 = 56,
     OR_TYPEID_PANASONIC_FZ35 = 57,
+    OR_TYPEID_PANASONIC_FZ38 = OR_TYPEID_PANASONIC_FZ35,
     OR_TYPEID_PANASONIC_ZS200 = 58,
     OR_TYPEID_PANASONIC_TX2 = OR_TYPEID_PANASONIC_ZS200,
     OR_TYPEID_PANASONIC_TZ202 = OR_TYPEID_PANASONIC_ZS200,
@@ -741,10 +776,13 @@ enum _OR_TYPEID_VENDOR_PANASONIC {
     OR_TYPEID_PANASONIC_DC_FZ1000M2 = 66,
     OR_TYPEID_PANASONIC_DC_ZS80 = 67,
     OR_TYPEID_PANASONIC_DC_TZ95 = OR_TYPEID_PANASONIC_DC_ZS80,
+    OR_TYPEID_PANASONIC_DC_TZ96 = OR_TYPEID_PANASONIC_DC_ZS80,
     OR_TYPEID_PANASONIC_GF10 = 68,
     OR_TYPEID_PANASONIC_GX880 = OR_TYPEID_PANASONIC_GF10,
     OR_TYPEID_PANASONIC_DC_G99 = 69,
+    OR_TYPEID_PANASONIC_DC_G90 = OR_TYPEID_PANASONIC_DC_G99,
     OR_TYPEID_PANASONIC_DC_G91 = OR_TYPEID_PANASONIC_DC_G99,
+    OR_TYPEID_PANASONIC_DC_G95D = OR_TYPEID_PANASONIC_DC_G99,
     OR_TYPEID_PANASONIC_DC_S1H = 70,
     OR_TYPEID_PANASONIC_DC_G100 = 71,
     OR_TYPEID_PANASONIC_DC_G110 = OR_TYPEID_PANASONIC_DC_G100,
@@ -752,6 +790,24 @@ enum _OR_TYPEID_VENDOR_PANASONIC {
     OR_TYPEID_PANASONIC_GH5M2 = 73,
     OR_TYPEID_PANASONIC_GH6 = 74,
     OR_TYPEID_PANASONIC_G7 = 75,
+    OR_TYPEID_PANASONIC_G70 = OR_TYPEID_PANASONIC_G7,
+
+    OR_TYPEID_PANASONIC_ZS40 = 76,
+    OR_TYPEID_PANASONIC_TZ60 = OR_TYPEID_PANASONIC_ZS40,
+    OR_TYPEID_PANASONIC_TZ61 = OR_TYPEID_PANASONIC_ZS40,
+    OR_TYPEID_PANASONIC_G6 = 77,
+    OR_TYPEID_PANASONIC_G8 = 78,
+    OR_TYPEID_PANASONIC_G81 = OR_TYPEID_PANASONIC_G8,
+    OR_TYPEID_PANASONIC_LF1 = 79,
+    OR_TYPEID_PANASONIC_FZ300 = 80,
+    OR_TYPEID_PANASONIC_FZ70 = 81,
+    OR_TYPEID_PANASONIC_FZ72 = OR_TYPEID_PANASONIC_FZ70,
+    OR_TYPEID_PANASONIC_ZS50 = 82,
+    OR_TYPEID_PANASONIC_TZ71 = OR_TYPEID_PANASONIC_ZS50,
+    OR_TYPEID_PANASONIC_ZS70 = 83,
+    OR_TYPEID_PANASONIC_TZ90 = OR_TYPEID_PANASONIC_ZS70,
+    OR_TYPEID_PANASONIC_DC_S5M2 = 84,
+    OR_TYPEID_PANASONIC_GF8 = 85,
     _OR_TYPEID_PANASONIC_LAST
 };
 
@@ -819,6 +875,13 @@ enum _OR_TYPEID_VENDOR_FUJIFILM {
     OR_TYPEID_FUJIFILM_GFX50S_II = 58,
     OR_TYPEID_FUJIFILM_GFX100S = 59,
     OR_TYPEID_FUJIFILM_XE4 = 60,
+    OR_TYPEID_FUJIFILM_XA10 = 61,
+    OR_TYPEID_FUJIFILM_XH2S = 62,
+    OR_TYPEID_FUJIFILM_XH2 = 63,
+    OR_TYPEID_FUJIFILM_XT5 = 64,
+    OR_TYPEID_FUJIFILM_HS50EXR = 65,
+    OR_TYPEID_FUJIFILM_S6000FD = 66,
+    OR_TYPEID_FUJIFILM_SL1000 = 67,
     _OR_TYPEID_FUJIFILM_LAST
 };
 
@@ -871,6 +934,7 @@ enum _OR_TYPEID_VENDOR_HASSELBLAD {
     OR_TYPEID_HASSELBLAD_UNKNOWN = 0,
     OR_TYPEID_HASSELBLAD_LUNAR = 1,
     OR_TYPEID_HASSELBLAD_L1D_20C = 2,
+    OR_TYPEID_HASSELBLAD_L2D_20C = 2,
 
     _OR_TYPEID_HASSELBLAD_LAST
 };
@@ -889,6 +953,7 @@ enum _OR_TYPEID_VENDOR_DJI {
     OR_TYPEID_DJI_OSMO_ACTION = 3,
     OR_TYPEID_DJI_FC220 = 4,
     OR_TYPEID_DJI_FC6310 = 5,
+    OR_TYPEID_DJI_FC3582 = 6, // DJI Mini 3 Pro
 
     _OR_TYPEID_DJI_LAST
 };
